/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'iframe', 'it', {
	border: 'Mostra il bordo',
	noUrl: 'Inserire l\'URL del campo IFrame',
	scrolling: 'Abilita scrollbar',
	title: 'Proprietà IFrame',
	toolbar: 'IFrame',
	tabindex: 'Rimuovi da tabindex'
} );
